summaryrefslogtreecommitdiffstats
path: root/ktouch/src/ktouchstatisticsdata.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'ktouch/src/ktouchstatisticsdata.cpp')
-rw-r--r--ktouch/src/ktouchstatisticsdata.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/ktouch/src/ktouchstatisticsdata.cpp b/ktouch/src/ktouchstatisticsdata.cpp
index f1b60dd0..80c92bef 100644
--- a/ktouch/src/ktouchstatisticsdata.cpp
+++ b/ktouch/src/ktouchstatisticsdata.cpp
@@ -41,7 +41,7 @@ int KTouchCharStats::missHitRatio() const {
// ----------------------------------------------------------------------------
TQTextStream& operator<<(TQTextStream &out, const KTouchCharStats &ch) {
- return (out << ch.m_char.tqunicode() << " " << ch.m_correctCount << " " << ch.m_wrongCount);
+ return (out << ch.m_char.unicode() << " " << ch.m_correctCount << " " << ch.m_wrongCount);
}
// ----------------------------------------------------------------------------
@@ -135,10 +135,10 @@ void KTouchLevelStats::write(TQDomDocument& doc, TQDomElement& root) const {
level.appendChild(e);
// add char stats
TQString char_data;
// we append for each missed char the char-tqunicode and the counters
for (std::set<KTouchCharStats>::const_iterator it=m_charStats.begin(); it!=m_charStats.end(); ++it)
- char_data += TQString(" %1 %2 %3").tqarg(it->m_char.tqunicode())
- .tqarg(it->m_correctCount).tqarg(it->m_wrongCount);
+ char_data += TQString(" %1 %2 %3").arg(it->m_char.unicode())
+ .arg(it->m_correctCount).arg(it->m_wrongCount);
e = doc.createElement("CharStats");
tn = doc.createTextNode(char_data);
e.appendChild(tn);
@@ -295,17 +295,17 @@ void KTouchSessionStats::write(TQDomDocument& doc, TQDomElement& root) const {
// add levels
TQString level_nums;
for (std::set<unsigned int>::const_iterator it = m_levelNums.begin(); it != m_levelNums.end(); ++it)
- level_nums += TQString( " %1").tqarg(*it);
+ level_nums += TQString( " %1").arg(*it);
e = doc.createElement("LevelNums");
tn = doc.createTextNode(level_nums);
e.appendChild(tn);
session.appendChild(e);
// add char data
TQString char_data;
// we append for each missed char the char-tqunicode and the counters
for (std::set<KTouchCharStats>::const_iterator it=m_charStats.begin(); it!=m_charStats.end(); ++it)
- char_data += TQString(" %1 %2 %3").tqarg(it->m_char.tqunicode())
- .tqarg(it->m_correctCount).tqarg(it->m_wrongCount);
+ char_data += TQString(" %1 %2 %3").arg(it->m_char.unicode())
+ .arg(it->m_correctCount).arg(it->m_wrongCount);
e = doc.createElement("CharStats");
tn = doc.createTextNode(char_data);
e.appendChild(tn);
@@ -135,10 +135,10 @@ void KTouchLevelStats::write(TQDomDocument& doc, TQDomElement& root) const {
// add char stats
TQString char_data;
- // we append for each missed char the char-tqunicode and the counters
+ // we append for each missed char the char-unicode and the counters
for (std::set<KTouchCharStats>::const_iterator it=m_charStats.begin(); it!=m_charStats.end(); ++it)
@@ -295,17 +295,17 @@ void KTouchSessionStats::write(TQDomDocument& doc, TQDomElement& root) const {
// add char data
TQString char_data;
- // we append for each missed char the char-tqunicode and the counters
+ // we append for each missed char the char-unicode and the counters
for (std::set<KTouchCharStats>::const_iterator it=m_charStats.begin(); it!=m_charStats.end(); ++it)